@@ -69,8 +69,6 @@ extern "C"
     }
 }
 
-static KScienceSaver *saver = 0;
-
 static struct {
 	QString name;
 	bool inverseEnable;
@@ -690,14 +688,14 @@ void KScienceSaver::slotTimeout()
 		}
 	}
 
-	if( (unsigned int) xd + w >= width()  ) w = width()  - xd - 1;
-	if( (unsigned int) yd + h >= height() ) h = height() - yd - 1;
+	if(  xd + w >= width()  ) w = width()  - xd - 1;
+	if(  yd + h >= height() ) h = height() - yd - 1;
 
 //printf("%d: (dx: %3d, dy: %3d), diam: %3d, (xc: %3d, yc: %3d), (xs: %3d, ys: %3d), (xd: %3d, yd: %3d), (w: %3d, h: %3d)\n", mode, dx, dy, diam, xcoord, ycoord, xs, ys, xd, yd, w, h);
 	myAssert( dx <= border && dy <=border, "assertion violated: dx or dy <= border");
 	myAssert( xcoord >= 0 && ycoord >= 0, "assertion violated: xcoord, ycoord >= 0 ");
-	myAssert( (unsigned int) xd+w < width(), "assertion violated: xd+w < width" );
-	myAssert( (unsigned int) yd+h < height(), "assertion violated: yd+h < height" );
+	myAssert( xd+w < width(), "assertion violated: xd+w < width" );
+	myAssert( yd+h < height(), "assertion violated: yd+h < height" );
 
 	if( hideBG[mode] )
 		blackPixel( xcoord, ycoord );
