@@ -21,8 +21,8 @@
  *
  *	You should have received a copy of the GNU Library General Public License
  *	along with this library; see the file COPYING.LIB.  If not, write to
- *	the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *	Boston, MA 02111-1307, USA.
+ *	the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *	Boston, MA 02110-1301, USA.
  */
 #include <qstyleplugin.h>
 #include <qstylefactory.h>
@@ -476,7 +476,7 @@ void dotNETstyle::drawPrimitive(PrimitiveElement pe,
 			QPixmap buffer(2,2);
 			QRect br(buffer.rect() );
 			QPainter bp(&buffer);
- 
+
 			if (on || down) {
 				bp.fillRect(br, QBrush(cg.mid().dark()));
 			} else {
@@ -1063,7 +1063,7 @@ void dotNETstyle::drawControl(ControlElement element,
 			if (btnDefault) {
 				drawPrimitive(PE_ButtonDefault, p, r, cg, flags);
 			}
-			
+
 			drawPrimitive(PE_ButtonBevel, p, br, cg, flags);
 			break;
 		}
@@ -1074,7 +1074,7 @@ void dotNETstyle::drawControl(ControlElement element,
 			const int text_flags = AlignVCenter | AlignHCenter | ShowPrefix |
 			                       DontClip | SingleLine;
 			QRect ur(r);
-			
+
 			if (flags & Style_Down) {
 				p->translate(pixelMetric(PM_ButtonShiftHorizontal),
 				             pixelMetric(PM_ButtonShiftVertical));
@@ -1087,14 +1087,14 @@ void dotNETstyle::drawControl(ControlElement element,
 			if (pb->iconSet() && !pb->iconSet()->isNull()) {
 				QIconSet::Mode mode = enabled ? QIconSet::Normal : QIconSet::Disabled;
 				QPixmap pixmap = pb->iconSet()->pixmap(QIconSet::Small, mode);
-				
+
 				if (!pb->text().isEmpty())
 				{
 					const int TextToIconMargin = 3;
 					int length = pixmap.width() + TextToIconMargin
 					              + p->fontMetrics().size(ShowPrefix, pb->text()).width();
 					int offset = (r.width() - length)/2;
-					
+
 					p->drawPixmap( r.x() + offset, r.y() + r.height() / 2 - pixmap.height() / 2, pixmap );
 					ur.addCoords(offset + pixmap.width() + TextToIconMargin, 0, -offset, 0);
 				}
@@ -1103,7 +1103,7 @@ void dotNETstyle::drawControl(ControlElement element,
 					if (!pb->pixmap())
 						p->drawPixmap(r.x() + r.width()/2 - pixmap.width()/2, r.y() + r.height() / 2 - pixmap.height() / 2,
 										pixmap);
-					else  //icon + pixmap. Ugh. 
+					else  //icon + pixmap. Ugh.
 						p->drawPixmap(r.x() + pb->isDefault() ? 8 : 4 , r.y() + r.height() / 2 - pixmap.height() / 2, pixmap);
 				}
 			}
@@ -1955,7 +1955,7 @@ QSize dotNETstyle::sizeFromContents(ContentsType t,
 
 			if (boldTextWidth > origTextWidth) //this might not happen in particular when text is empty
 				w += boldTextWidth - origTextWidth;
-			
+
 			w += bm + fw;
 			h += bm + fw;
 
@@ -1964,7 +1964,7 @@ QSize dotNETstyle::sizeFromContents(ContentsType t,
 				if ( w < 80 && !button->pixmap() )
 					w = 80;
 			}
-				
+
 			// Compensate for default indicator. Doing it for all widgets lets us
 			// workaround changes in auto-default behavior in KDialogBase in 3.3
 			int di = pixelMetric( PM_ButtonDefaultIndicator );
